@@ -26,7 +26,7 @@ from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
 app_name = "ReText"
-app_version = "2.1.3"
+app_version = "2.1.4"
 
 settings = QSettings('ReText project', 'ReText')
 
@@ -55,6 +55,7 @@ else:
 
 try:
 	import enchant
+	enchant.Dict()
 except:
 	use_enchant = False
 else:
@@ -621,7 +622,11 @@ class ReTextWindow(QMainWindow):
 		global dictionary
 		if yes:
 			if self.sl:
-				dictionary = enchant.Dict(self.sl)
+				try:
+					dictionary = enchant.Dict(self.sl)
+				except Exception as e:
+					QMessageBox.warning(self, app_name, str(e))
+					dictionary = enchant.Dict()
 			else:
 				dictionary = enchant.Dict()
 			settings.setValue('spellCheck', True)
@@ -748,7 +753,10 @@ class ReTextWindow(QMainWindow):
 		for i in filesOld:
 			if QFile.exists(i):
 				files.append(i)
-		settings.setValue("recentFileList", files)
+		if files:
+			settings.setValue("recentFileList", files)
+		else:
+			settings.remove("recentFileList")
 		item, ok = QInputDialog.getItem(self, app_name, self.tr("Open recent"), files, 0, False)
 		if ok and not item.isEmpty():
 			self.openFileWrapper(item)
@@ -950,14 +958,14 @@ class ReTextWindow(QMainWindow):
 			return QMessageBox.warning(self, app_name, self.tr('This function is not available in Plain text mode!'))
 		settings.beginGroup('Export')
 		types = settings.allKeys()
-		settings.endGroup()
 		item, ok = QInputDialog.getItem(self, app_name, self.tr('Select type'), types, 0, False)
 		if ok:
 			fileName = QFileDialog.getSaveFileName(self, self.tr('Export document'))
+			command = settings.value(item).toString()
+		settings.endGroup()
 		if ok and fileName:
 			if QFileInfo(fileName).suffix().isEmpty():
 				fileName.append('.'+item)
-			command = settings.value(item).toString()
 			tmpname = 'temp.rst' if self.getParser() == PARSER_DOCUTILS else 'temp.mkd'
 			command.replace('%of', 'out.'+item)
 			command.replace('%if', tmpname)
@@ -985,7 +993,9 @@ class ReTextWindow(QMainWindow):
 		if realTitle and not baseName:
 			return realTitle
 		elif self.fileNames[self.ind]:
-			return QFileInfo(self.fileNames[self.ind]).completeBaseName()
+			fileinfo = QFileInfo(self.fileNames[self.ind])
+			basename = fileinfo.completeBaseName()
+			return (basename if basename else fileinfo.fileName())
 		else:
 			return self.tr("New document")
 	
