@@ -1,20 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="fr">
+<!DOCTYPE TS><TS version="2.0" language="fr" sourcelanguage="">
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="141"/>
+        <location filename="retext.py" line="142"/>
         <source>Enter your Google account data</source>
         <translation>Entrez vos données du compte Google</translation>
     </message>
     <message>
-        <location filename="retext.py" line="150"/>
+        <location filename="retext.py" line="151"/>
         <source>Username</source>
         <translation>Utilisateur</translation>
     </message>
     <message>
-        <location filename="retext.py" line="151"/>
+        <location filename="retext.py" line="152"/>
         <source>Password</source>
         <translation>Mot de passe</translation>
     </message>
@@ -22,409 +21,409 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="1099"/>
+        <location filename="retext.py" line="1111"/>
         <source>New document</source>
         <translation>Nouveau document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="211"/>
+        <location filename="retext.py" line="212"/>
         <source>File toolbar</source>
         <translation>Barre d&apos;outil Fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="213"/>
+        <location filename="retext.py" line="214"/>
         <source>Edit toolbar</source>
         <translation>Barre d&apos;outil Édition</translation>
     </message>
     <message>
-        <location filename="retext.py" line="215"/>
+        <location filename="retext.py" line="216"/>
         <source>Search toolbar</source>
         <translation>Barre d&apos;outil Rechercher</translation>
     </message>
     <message>
-        <location filename="retext.py" line="217"/>
+        <location filename="retext.py" line="218"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="retext.py" line="221"/>
+        <location filename="retext.py" line="222"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="225"/>
+        <location filename="retext.py" line="226"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="230"/>
+        <location filename="retext.py" line="231"/>
         <source>Save as</source>
         <translation>Enregistrer Sous</translation>
     </message>
     <message>
-        <location filename="retext.py" line="233"/>
+        <location filename="retext.py" line="234"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="237"/>
+        <location filename="retext.py" line="238"/>
         <source>Print preview</source>
         <translation>Aperçu d&apos;impression</translation>
     </message>
     <message>
-        <location filename="retext.py" line="239"/>
+        <location filename="retext.py" line="240"/>
         <source>View HTML code</source>
         <translation>Voir code HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="241"/>
+        <location filename="retext.py" line="242"/>
         <source>Change default font</source>
         <translation>Changer police par défaut</translation>
     </message>
     <message>
-        <location filename="retext.py" line="243"/>
+        <location filename="retext.py" line="244"/>
         <source>Find text</source>
         <translation>Chercher text</translation>
     </message>
     <message>
-        <location filename="retext.py" line="248"/>
+        <location filename="retext.py" line="249"/>
         <source>Preview</source>
         <translation>Aperçu</translation>
     </message>
     <message>
-        <location filename="retext.py" line="260"/>
+        <location filename="retext.py" line="261"/>
         <source>Live preview</source>
         <translation>Aperçu live</translation>
     </message>
     <message>
-        <location filename="retext.py" line="264"/>
+        <location filename="retext.py" line="265"/>
         <source>Fullscreen mode</source>
         <translation>Mode plein écran</translation>
     </message>
     <message>
-        <location filename="retext.py" line="276"/>
+        <location filename="retext.py" line="277"/>
         <source>Other formats</source>
         <translation>Autres formats</translation>
     </message>
     <message>
-        <location filename="retext.py" line="282"/>
+        <location filename="retext.py" line="283"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="retext.py" line="286"/>
+        <location filename="retext.py" line="287"/>
         <source>Undo</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="retext.py" line="288"/>
+        <location filename="retext.py" line="289"/>
         <source>Redo</source>
         <translation>Rétablir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="292"/>
+        <location filename="retext.py" line="293"/>
         <source>Copy</source>
         <translation>Copier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="295"/>
+        <location filename="retext.py" line="296"/>
         <source>Cut</source>
         <translation>Couper</translation>
     </message>
     <message>
-        <location filename="retext.py" line="298"/>
+        <location filename="retext.py" line="299"/>
         <source>Paste</source>
         <translation>Coller</translation>
     </message>
     <message>
-        <location filename="retext.py" line="314"/>
+        <location filename="retext.py" line="315"/>
         <source>Enable</source>
         <translation>Activer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="316"/>
+        <location filename="retext.py" line="317"/>
         <source>Set locale</source>
         <translation>choisir langue</translation>
     </message>
     <message>
-        <location filename="retext.py" line="327"/>
+        <location filename="retext.py" line="328"/>
         <source>Plain text</source>
         <translation>Format Text</translation>
     </message>
     <message>
-        <location filename="retext.py" line="751"/>
+        <location filename="retext.py" line="760"/>
         <source>Open recent</source>
         <translation>Ouvrir récent</translation>
     </message>
     <message>
-        <location filename="retext.py" line="333"/>
+        <location filename="retext.py" line="334"/>
         <source>Generate webpages</source>
         <translation>Générer pages web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="335"/>
+        <location filename="retext.py" line="336"/>
         <source>Show</source>
         <translation>Montrer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="337"/>
+        <location filename="retext.py" line="338"/>
         <source>Next</source>
         <translation>Suivant</translation>
     </message>
     <message>
-        <location filename="retext.py" line="339"/>
+        <location filename="retext.py" line="340"/>
         <source>Previous</source>
         <translation>Précédent</translation>
     </message>
     <message>
-        <location filename="retext.py" line="343"/>
+        <location filename="retext.py" line="344"/>
         <source>Get help online</source>
         <translation>Aide en ligne</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1111"/>
+        <location filename="retext.py" line="1123"/>
         <source>About %1</source>
         <translation>À propos de  %1</translation>
     </message>
     <message>
-        <location filename="retext.py" line="348"/>
+        <location filename="retext.py" line="349"/>
         <source>About Qt</source>
         <translation>À propos de Qt</translation>
     </message>
     <message>
-        <location filename="retext.py" line="369"/>
+        <location filename="retext.py" line="370"/>
         <source>Save to Google Docs</source>
         <translation>Enregistrer sur Google Docs</translation>
     </message>
     <message>
-        <location filename="retext.py" line="375"/>
+        <location filename="retext.py" line="376"/>
         <source>Tags</source>
         <translation>Tags</translation>
     </message>
     <message>
-        <location filename="retext.py" line="379"/>
+        <location filename="retext.py" line="380"/>
         <source>Symbols</source>
         <translation>Symboles</translation>
     </message>
     <message>
-        <location filename="retext.py" line="393"/>
+        <location filename="retext.py" line="394"/>
         <source>File</source>
         <translation>Fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="394"/>
+        <location filename="retext.py" line="395"/>
         <source>Edit</source>
         <translation>Édition</translation>
     </message>
     <message>
-        <location filename="retext.py" line="395"/>
+        <location filename="retext.py" line="396"/>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
     <message>
-        <location filename="retext.py" line="399"/>
+        <location filename="retext.py" line="400"/>
         <source>Directory</source>
         <translation>Répertoire</translation>
     </message>
     <message>
-        <location filename="retext.py" line="407"/>
+        <location filename="retext.py" line="408"/>
         <source>Export</source>
         <translation>Exporter</translation>
     </message>
     <message>
-        <location filename="retext.py" line="428"/>
+        <location filename="retext.py" line="429"/>
         <source>Spell check</source>
         <translation>Vérificateur</translation>
     </message>
     <message>
-        <location filename="retext.py" line="436"/>
+        <location filename="retext.py" line="437"/>
         <source>Default editing mode</source>
         <translation>Mode d&apos;édition par défaut</translation>
     </message>
     <message>
-        <location filename="retext.py" line="471"/>
+        <location filename="retext.py" line="472"/>
         <source>Search</source>
         <translation>Chercher</translation>
     </message>
     <message>
-        <location filename="retext.py" line="475"/>
+        <location filename="retext.py" line="476"/>
         <source>Case sensitively</source>
         <translation>Respect de la casse</translation>
     </message>
     <message>
-        <location filename="retext.py" line="492"/>
+        <location filename="retext.py" line="493"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>Vous n&apos;avez pas Markdown, ni Docutils d&apos;installé !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="492"/>
+        <location filename="retext.py" line="493"/>
         <source>Only HTML formatting will be available.</source>
         <translation>Seulement le format HTML sera disponible.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="636"/>
+        <location filename="retext.py" line="642"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Entrez le préfix pour la lagnue (exemple: fr_FR)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="725"/>
+        <location filename="retext.py" line="731"/>
         <source>Please, save the file somewhere.</source>
         <translation>SVP, enregistrer le fichier quelque part.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="712"/>
+        <location filename="retext.py" line="718"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Pages enregistrés dans le répertoire &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="756"/>
+        <location filename="retext.py" line="765"/>
         <source>Select one or several files to open</source>
         <translation>choisir un ou plusieurs fichiers pour ouvrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="756"/>
+        <location filename="retext.py" line="765"/>
         <source>Supported files</source>
         <translation>Formats supportés</translation>
     </message>
     <message>
-        <location filename="retext.py" line="756"/>
+        <location filename="retext.py" line="765"/>
         <source>All files (*)</source>
         <translation>Tous fichiers (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="810"/>
+        <location filename="retext.py" line="819"/>
         <source>Plain text (*.txt)</source>
         <translation>Fichier text (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="813"/>
+        <location filename="retext.py" line="822"/>
         <source>ReStructuredText files</source>
         <translation>Fichiers ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="816"/>
+        <location filename="retext.py" line="825"/>
         <source>HTML files</source>
         <translation>Fichiers HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="819"/>
+        <location filename="retext.py" line="828"/>
         <source>Markdown files</source>
         <translation>Fichiers Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="899"/>
+        <location filename="retext.py" line="908"/>
         <source>Save file</source>
         <translation>Enregistrer fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="890"/>
+        <location filename="retext.py" line="899"/>
         <source>Export document to ODT</source>
         <translation>Exporter document vers ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="890"/>
+        <location filename="retext.py" line="899"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fichier text OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="899"/>
+        <location filename="retext.py" line="908"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fichier HTML (*.html, *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="915"/>
+        <location filename="retext.py" line="924"/>
         <source>Export document to PDF</source>
         <translation>Exporter document vers PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="915"/>
+        <location filename="retext.py" line="924"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fichiers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="932"/>
+        <location filename="retext.py" line="941"/>
         <source>Print document</source>
         <translation>Imprimer document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="949"/>
+        <location filename="retext.py" line="958"/>
         <source>This function is not available in Plain text mode!</source>
         <translation>Cette fonctionnalité n&apos;est pas disponible en mode Texte !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="952"/>
+        <location filename="retext.py" line="961"/>
         <source>Select type</source>
         <translation>Choisir Type</translation>
     </message>
     <message>
-        <location filename="retext.py" line="954"/>
+        <location filename="retext.py" line="963"/>
         <source>Export document</source>
         <translation>Exporter document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1009"/>
+        <location filename="retext.py" line="1021"/>
         <source>Incorrect user name or password!</source>
         <translation>Utilisateur ou mot de passe incorrect !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1073"/>
+        <location filename="retext.py" line="1085"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Le document a changé.
 Voulez vous enregistrer vos changements ?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1102"/>
+        <location filename="retext.py" line="1114"/>
         <source>HTML code</source>
         <translation>Code HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1111"/>
+        <location filename="retext.py" line="1123"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>Éditeur de Markdown et ReStructuredText simple mais puissant</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1111"/>
+        <location filename="retext.py" line="1123"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Auteur :Dmity Schachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1111"/>
+        <location filename="retext.py" line="1123"/>
         <source>Website</source>
         <translation>Site Web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1111"/>
+        <location filename="retext.py" line="1123"/>
         <source>Markdown syntax</source>
         <translation>Syntaxe Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1111"/>
+        <location filename="retext.py" line="1123"/>
         <source>ReST syntax</source>
         <translation>Syntaxe Rest</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1170"/>
+        <location filename="retext.py" line="1182"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>Ne peut analyser le contenu du fichier, vérifier si les modules sont bien installés</translation>
     </message>
     <message>
-        <location filename="retext.py" line="714"/>
+        <location filename="retext.py" line="720"/>
         <source>Show directory</source>
         <translation>Montrer répertoire</translation>
     </message>
     <message>
-        <location filename="retext.py" line="719"/>
+        <location filename="retext.py" line="725"/>
         <source>Webpages generator is not installed!</source>
         <translation>Générateur Webpages non installé !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="835"/>
+        <location filename="retext.py" line="844"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Ne peut enregistrer le fichier car en lecture seule !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1011"/>
+        <location filename="retext.py" line="1023"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>Authentification echouée, svp vérifier votre connection internet !</translation>
     </message>
