@@ -39,7 +39,7 @@ else:
 	use_docutils = True
 
 app_name = "ReText Webpages generator"
-app_version = "0.4.2"
+app_version = "0.4.3"
 app_site = "http://sourceforge.net/p/retext/"
 
 if os.path.exists("/usr/share/wpgen/"):
@@ -95,6 +95,11 @@ class WebLibrary(object):
 			pagename = bn
 		if html or bn == "index":
 			content = self.template
+			try:
+				pagename = unicode(pagename, 'utf-8')
+				bn = unicode(bn, 'utf-8')
+			except:
+				pass
 			content = content.replace("%CONTENT%", html)
 			content = content.replace("%PAGENAME%", pagename)
 			content = content.replace(" href=\""+bn+".html\"", "")
